%global pypi_name cryptography

%bcond_with tests

Name:           python-%{pypi_name}
Version:        3.3.1
Release:        %mkrel 1
Summary:        PyCA's cryptography library
Group:          Development/Python
License:        ASL 2.0 or BSD
URL:            https://pypi.org/project/cryptography/
Source0:        https://pypi.io/packages/source/c/cryptography/cryptography-%{version}.tar.gz
BuildRequires:  pkgconfig(openssl)

%description
cryptography is a package designed to expose cryptographic primitives and
recipes to Python developers.

%package -n  python3-%{pypi_name}
Group:          Development/Python
Summary:        %{summary}
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(cffi) >= 1.7
BuildRequires:  python3dist(six)
BuildRequires:  python3dist(cryptography-vectors) = %{version}
BuildRequires:  python3dist(pyasn1)
%if %{with tests}
BuildRequires:  python3dist(hypothesis)
BuildRequires:  python3dist(idna)
BuildRequires:  python3dist(iso8601)
BuildRequires:  python3dist(pretend)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytz)
%endif
BuildRequires:  python3dist(funcsigs)
BuildRequires:  python3dist(asn1crypto)
Requires:       openssl
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
cryptography is a package designed to expose cryptographic primitives and
recipes to Python developers.


%prep
%autosetup -n %{pypi_name}-%{version} -p1

# drop bundled egg-info
rm -rf src/*.egg-info

%build
%py3_build

%install
# Actually other *.c and *.h are appropriate
# see https://github.com/pyca/cryptography/issues/1463
find . -name .keep -print -delete

%py3_install

%if %{with tests}
%check
# workaround for pytest 3.2.0 bug https://github.com/pytest-dev/pytest/issues/2644
rm -f tests/hazmat/primitives/test_padding.py
%{__python3} setup.py test
%endif

%files -n python3-%{pypi_name}
%doc README.rst docs
%license LICENSE LICENSE.APACHE LICENSE.BSD
%{python3_sitearch}/*


%changelog
* Sun Dec 13 2020 guillomovitch <guillomovitch> 3.3.1-1.mga8
+ Revision: 1656427
- new version 3.3.1

* Sun Nov 01 2020 guillomovitch <guillomovitch> 3.2.1-1.mga8
+ Revision: 1641466
- new version 3.2.1

* Sat Sep 05 2020 guillomovitch <guillomovitch> 3.1-1.mga8
+ Revision: 1622539
- new version 3.1

* Thu Jul 16 2020 wally <wally> 2.9.2-2.mga8
+ Revision: 1606570
- add patch to drop boolean deps from generated requires

* Tue Jul 14 2020 guillomovitch <guillomovitch> 2.9.2-1.mga8
+ Revision: 1605987
- new version 2.9.2

* Thu Mar 05 2020 kekepower <kekepower> 2.8-1.mga8
+ Revision: 1554161
- Update to version 2.8

* Sun Feb 16 2020 umeabot <umeabot> 2.7-3.mga8
+ Revision: 1530733
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 wally <wally> 2.7-2.mga8
+ Revision: 1437365
- rebuild for python3.8
- drop python2 support

* Sat Aug 10 2019 shlomif <shlomif> 2.7-1.mga8
+ Revision: 1428499
- New version 2.7

* Wed Apr 17 2019 wally <wally> 2.6.1-1.mga7
+ Revision: 1392288
- new version 2.6.1

* Mon Jan 14 2019 luigiwalser <luigiwalser> 2.4.2-1.mga7
+ Revision: 1356243
- 2.4.2

* Sat Jan 05 2019 wally <wally> 2.4.1-3.mga7
+ Revision: 1349622
- rebuild for python3.7 without tests

* Tue Jan 01 2019 wally <wally> 2.4.1-2.mga7
+ Revision: 1348079
- build with tests

* Mon Dec 31 2018 luigiwalser <luigiwalser> 2.4.1-1.mga7
+ Revision: 1347714
- disable check for now as newer pytest is required
- 2.4.1

* Wed Oct 24 2018 bcornec <bcornec> 2.3.1-1.mga7
+ Revision: 1325064
- update to upstream python-cryptography 2.3.1

* Sun Sep 23 2018 umeabot <umeabot> 2.2.2-3.mga7
+ Revision: 1300463
- Mageia 7 Mass Rebuild

* Wed Jul 25 2018 daviddavid <daviddavid> 2.2.2-2.mga7
+ Revision: 1245162
- remove some hard requires that are already auto-required

* Fri Apr 20 2018 kekepower <kekepower> 2.2.2-1.mga7
+ Revision: 1220456
- Update to version 2.2.2
- Use python_provide

* Thu Jan 04 2018 guillomovitch <guillomovitch> 2.1.4-1.mga7
+ Revision: 1190122
- new version 2.1.4
- new version 2.1.4

* Thu Oct 05 2017 tv <tv> 2.0.3-4.mga7
+ Revision: 1169083
- add BR on python2dist(asn1crypto) thus fixing build

* Sun Aug 06 2017 neoclust <neoclust> 2.0.3-3.mga7
+ Revision: 1137753
- Add missing provide

* Sun Aug 06 2017 joequant <joequant> 2.0.3-2.mga7
+ Revision: 1137541
- convert to new conventions python

* Sat Aug 05 2017 philippem <philippem> 2.0.3-1.mga7
+ Revision: 1135143
- update to 2.0.3, rebuild for Python 3.6

* Fri Nov 11 2016 philippem <philippem> 1.5.3-1.mga6
+ Revision: 1066348
- update to 1.5.3, fix CVE-2016-9243 mga#19736

* Fri Oct 28 2016 philippem <philippem> 1.5.2-1.mga6
+ Revision: 1063822
- add BR on pytz
- update to 1.5.2

* Tue May 17 2016 philippem <philippem> 1.3.2-1.mga6
+ Revision: 1016543
- update to 1.3.2

* Sun Apr 10 2016 philippem <philippem> 1.3.1-1.mga6
+ Revision: 1000033
- update to 1.3.1

* Sat Mar 05 2016 philippem <philippem> 1.2.3-1.mga6
+ Revision: 986120
- update to 1.2.3
- update to 1.2.3
+ umeabot <umeabot>
- Rebuild for openssl

* Sat Feb 13 2016 philippem <philippem> 1.2.2-1.mga6
+ Revision: 959785
- update to 1.2.2

* Fri Dec 04 2015 philippem <philippem> 1.1.1-1.mga6
+ Revision: 908237
- add BR for tests, disable python3 tests
- update to 1.1.1

* Thu Oct 29 2015 philippem <philippem> 1.1-1.mga6
+ Revision: 896476
- update to 1.1

* Sun Oct 11 2015 philippem <philippem> 1.0.2-1.mga6
+ Revision: 889682
- update to 1.0.2

* Thu Oct 08 2015 tv <tv> 1.0.1-2.mga6
+ Revision: 887747
- rebuild for python 3.5

* Thu Sep 24 2015 philippem <philippem> 1.0.1-1.mga6
+ Revision: 883390
- update to 1.0.1

* Sun Mar 08 2015 philippem <philippem> 0.7.2-1.mga5
+ Revision: 818107
- imported package python-cryptography

